@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for ram service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_ram import RAMClient
-    from mypy_boto3_ram import (
+    from mypy_boto3_ram.paginator import (
         GetResourcePoliciesPaginator,
         GetResourceShareAssociationsPaginator,
         GetResourceShareInvitationsPaginator,
@@ -26,10 +27,11 @@ Usage::
     list_resources_paginator: ListResourcesPaginator = client.get_paginator("list_resources")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_ram.type_defs import (
     GetResourcePoliciesResponseTypeDef,
     GetResourceShareAssociationsResponseTypeDef,
@@ -59,7 +61,7 @@ __all__ = (
 
 class GetResourcePoliciesPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
+    [Paginator.GetResourcePolicies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourcePolicies)
     """
 
     def paginate(
@@ -69,13 +71,13 @@ class GetResourcePoliciesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourcePoliciesResponseTypeDef]:
         """
-        [GetResourcePolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
+        [GetResourcePolicies.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourcePolicies.paginate)
         """
 
 
 class GetResourceShareAssociationsPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourceShareAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
+    [Paginator.GetResourceShareAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations)
     """
 
     def paginate(
@@ -90,13 +92,13 @@ class GetResourceShareAssociationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourceShareAssociationsResponseTypeDef]:
         """
-        [GetResourceShareAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
+        [GetResourceShareAssociations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourceShareAssociations.paginate)
         """
 
 
 class GetResourceShareInvitationsPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourceShareInvitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
+    [Paginator.GetResourceShareInvitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations)
     """
 
     def paginate(
@@ -106,13 +108,13 @@ class GetResourceShareInvitationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourceShareInvitationsResponseTypeDef]:
         """
-        [GetResourceShareInvitations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
+        [GetResourceShareInvitations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourceShareInvitations.paginate)
         """
 
 
 class GetResourceSharesPaginator(Boto3Paginator):
     """
-    [Paginator.GetResourceShares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShares)
+    [Paginator.GetResourceShares documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourceShares)
     """
 
     def paginate(
@@ -125,13 +127,13 @@ class GetResourceSharesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[GetResourceSharesResponseTypeDef]:
         """
-        [GetResourceShares.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
+        [GetResourceShares.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.GetResourceShares.paginate)
         """
 
 
 class ListPrincipalsPaginator(Boto3Paginator):
     """
-    [Paginator.ListPrincipals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListPrincipals)
+    [Paginator.ListPrincipals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.ListPrincipals)
     """
 
     def paginate(
@@ -144,13 +146,13 @@ class ListPrincipalsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListPrincipalsResponseTypeDef]:
         """
-        [ListPrincipals.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
+        [ListPrincipals.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.ListPrincipals.paginate)
         """
 
 
 class ListResourcesPaginator(Boto3Paginator):
     """
-    [Paginator.ListResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListResources)
+    [Paginator.ListResources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.ListResources)
     """
 
     def paginate(
@@ -163,5 +165,5 @@ class ListResourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListResourcesResponseTypeDef]:
         """
-        [ListResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
+        [ListResources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.1/reference/services/ram.html#RAM.Paginator.ListResources.paginate)
         """
